@@ -2,7 +2,7 @@ from traceback import format_exc
 
 def detailed_error():
     ''' 
-    from stout.util import detailed_error
+    from stout.util.error import detailed_error
 
     try: create_error()
     except:
